data/data library

Compatibility exports for pagination data models.

Classes

SortOrder<T>
Configuration for sorting paginated items.
SortOrderCollection<T>
A collection of sort orders with a selected active order.
SuperPaginationMeta
Metadata describing the state of a paginated response.
SuperPaginationRequest
Lightweight request descriptor used by the pagination cubit.

Enums

SortDirection
Defines the direction of sorting.

Typedefs

ItemComparator<T> = int Function(T a, T b)
A comparator function that compares two items of type T.