core/core library
Compatibility exports for the former core entry point.
Classes
-
FutureSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Future-based pagination provider for standard REST APIs.
- IPaginationChangeListener
- Base interface for pagination change listeners that provides common functionality for both SuperPagination and DualPagination listeners.
-
IPaginationController<
T, R extends SuperPaginationRequest> - Base interface for pagination controllers that provides common functionality for both SuperPagination and DualPagination controllers.
-
IPaginationCubit<
T, StateType extends IPaginationState< T> , R extends SuperPaginationRequest> - Base interface for pagination cubits that provides common functionality for both SuperPagination and DualPagination cubits.
-
IPaginationErrorState<
T> - Base interface for error pagination states.
-
IPaginationFilterChangeListener<
T> - Base interface for pagination filter listeners.
-
IPaginationInitialState<
T> - Base interface for pagination states that provides common functionality for both SuperPagination and DualPagination states.
-
IPaginationListCubit<
T, StateType extends IPaginationState< T> , R extends SuperPaginationRequest> - Base interface for pagination cubits with list building capabilities.
-
IPaginationLoadedState<
T> - Base interface for loaded pagination states.
-
IPaginationOrderChangeListener<
T> - Base interface for pagination order listeners.
- IPaginationRefreshedChangeListener
- Base interface for pagination refresh listeners.
-
IPaginationScrollController<
T, R extends SuperPaginationRequest> - Base interface for pagination controllers with scroll capabilities.
-
IPaginationState<
T> - Base interface for pagination states that provides common functionality for both SuperPagination and DualPagination states.
-
MergedStreamSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Merged streams pagination provider that combines multiple streams into one.
-
StreamSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Stream-based pagination provider for real-time updates.
-
SuperPaginationProvider<
T, R extends SuperPaginationRequest> - Unified pagination data provider that can be either Future-based or Stream-based.
Typedefs
-
CompareBy<
T> = int Function(T a, T b) -
InsertAllCallback<
T> = void Function(List< T> currentItems, Iterable<T> newItems) - Signature for a callback function that is called when items are inserted.
-
ListBuilder<
T> = List< T> Function(List<T> list) - Signature for a function that builds a list from fetched items.
-
OnInsertionCallback<
T> = void Function(List< T> items) -
PaginationDataProvider<
T> = Future< List< Function(SuperPaginationRequest request)T> > - Legacy typedef for backward compatibility (will be deprecated).
-
PaginationStreamProvider<
T> = Stream< List< Function(SuperPaginationRequest request)T> > - Legacy typedef for backward compatibility (will be deprecated).
-
WhereChecker<
T> = bool Function(T item)