pagination library
Compatibility entry point.
Existing imports can keep using pagination.dart; new code may use
package:super_pagination/super_pagination.dart.
Classes
- AlignedGridView
- A scrollable, 2D array of widgets placed according to the aligned layout.
- BottomLoader
- ChatObserverBouncingScrollPhysics
- Bouncing scroll physics designed for chat scroll observer.
- ChatObserverClampingScrollPhysics
- ChatObserverClampinScrollPhysics
- Deprecated scroll physics for chat observer clamping scroll physics. Use ChatObserverClampingScrollPhysics instead.
- ChatScrollObserver
- ChatScrollObserverCustomAdjustPositionDeltaModel
- ChatScrollObserverCustomAdjustPositionModel
- ChatScrollObserverHandlePositionResultModel
-
CommonOnceObserveNotificationResult<
M extends ObserveModel, R extends ObserverHandleContextsResultModel< M> > - CustomErrorBuilder
- A customizable error widget builder for pagination errors.
- EmptyDisplay
- EmptySeparator
- ErrorDisplay
-
FutureSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Future-based pagination provider for standard REST APIs.
- GridObserverController
- GridViewObserveDisplayingChildModel
- GridViewObserveModel
- GridViewObserver
- GridViewObserverState
- GridViewOnceObserveNotification
- The Notification for Triggering an GridView observation
- GridViewOnceObserveNotificationResult
- InitialLoader
- IPaginationChangeListener
- Base interface for pagination change listeners that provides common functionality for both SuperPagination and DualPagination listeners.
-
IPaginationController<
T, R extends SuperPaginationRequest> - Base interface for pagination controllers that provides common functionality for both SuperPagination and DualPagination controllers.
-
IPaginationCubit<
T, StateType extends IPaginationState< T> , R extends SuperPaginationRequest> - Base interface for pagination cubits that provides common functionality for both SuperPagination and DualPagination cubits.
-
IPaginationErrorState<
T> - Base interface for error pagination states.
-
IPaginationFilterChangeListener<
T> - Base interface for pagination filter listeners.
-
IPaginationInitialState<
T> - Base interface for pagination states that provides common functionality for both SuperPagination and DualPagination states.
-
IPaginationListCubit<
T, StateType extends IPaginationState< T> , R extends SuperPaginationRequest> - Base interface for pagination cubits with list building capabilities.
-
IPaginationLoadedState<
T> - Base interface for loaded pagination states.
-
IPaginationOrderChangeListener<
T> - Base interface for pagination order listeners.
- IPaginationRefreshedChangeListener
- Base interface for pagination refresh listeners.
-
IPaginationScrollController<
T, R extends SuperPaginationRequest> - Base interface for pagination controllers with scroll capabilities.
-
IPaginationState<
T> - Base interface for pagination states that provides common functionality for both SuperPagination and DualPagination states.
- ListObserverController
- ListViewObserveDisplayingChildModel
- ListViewObserveModel
- ListViewObserver
- ListViewObserverState
- ListViewOnceObserveNotification
- The Notification for Triggering an ListView observation
- ListViewOnceObserveNotificationResult
- MasonryGridView
- A scrollable, 2D array of widgets placed according to the masonry layout.
-
MergedStreamSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Merged streams pagination provider that combines multiple streams into one.
- MixViewObserverState
- NestedScrollUtil
- ObserveDisplayingChildModel
- ObserveModel
- ObserverCore
- ObserverIndexPositionModel
- ObserverScrollDecisionNotification
- A notification that the data of the specified index item is determined during the execution of the scrolling task.
- ObserverScrollEndNotification
-
A notification that a scrolling task has stopped due to calling the jumpTo
or animateTo method of
ObserverController. - ObserverScrollInterruptionNotification
-
A notification that a scrolling task has interrupted due to calling the
jumpTo or animateTo method of
ObserverController. - ObserverScrollNotification
- A notification of scrolling task.
- ObserverScrollStartNotification
-
A notification that a scrolling task has started due to calling the jumpTo
or animateTo method of
ObserverController. - ObserverUtils
- OverlayPositionData
- Calculated position and size for the overlay.
- OverlayPositioner
- Utility class for calculating overlay position.
-
PaginateApiView<
T, R extends SuperPaginationRequest> - A paginated view widget that automatically integrates scrollview_observer for programmatic scroll navigation (animateToIndex, jumpToIndex, etc.)
- PaginationOperation
- Describes the last item-level operation that triggered a state emission.
- PaginationOperationInsert
- An item was inserted at index. count items were inserted.
- PaginationOperationNone
- No operation — default state.
- PaginationOperationRefresh
- A single item at index was refreshed from the server.
- PaginationOperationReload
- A full reload occurred (clear, setItems, fetch).
- PaginationOperationRemove
- An item was removed at index. count items were removed. If index is -1, the exact indices are unknown (e.g., removeWhere).
- PaginationOperationUpdate
- Items at indices were updated in place.
- QuiltedGridRepeatPattern
- Defines how a pattern is repeating.
- QuiltedGridTile
- A tile for SliverQuiltedGridDelegate.
- RenderSliverMasonryGrid
- A sliver that places multiple box children in a two dimensional arrangement.
- RetryConfig
- Configuration for retry behavior.
- RetryHandler
- Utility class for executing functions with retry and timeout logic.
- ScrollViewOnceObserveNotification
- ScrollViewOnceObserveNotificationResult
- SliverAlignedGrid
- A sliver that places multiple box children in a two dimensional arrangement.
- SliverMasonryGrid
- A sliver that places multiple box children in a two dimensional arrangement.
- SliverMasonryGridParentData
- Parent data structure used by RenderSliverMasonryGrid.
- SliverObserveContext
- SliverObserveContextToBoxAdapter
- SliverObserverController
- SliverQuiltedGridDelegate
- Controls the layout of a quilted grid.
- SliverSimpleGridDelegate
- Controls the layout of tiles in a some slivers.
- SliverSimpleGridDelegateWithFixedCrossAxisCount
- Creates grid layouts with a fixed number of tiles in the cross axis.
- SliverSimpleGridDelegateWithMaxCrossAxisExtent
- Creates grid layouts with tiles that each have a maximum cross-axis extent.
- SliverStairedGridDelegate
- Controls the layout of tiles in a staired grid.
- SliverViewObserver
- SliverViewportObserveDisplayingChildModel
- SliverViewportObserveModel
- SliverWovenGridDelegate
- Controls the layout of tiles in a woven grid.
-
SortOrder<
T> - Configuration for sorting paginated items.
-
SortOrderCollection<
T> - A collection of sort orders with a selected active order.
- StaggeredGrid
- A grid which lays out children in a staggered arrangement. Each child can have a different size. Wrap your children with a StaggeredGridTile to specify their size if it's different from a 1x1 tile.
- StaggeredGridTile
- Represents the size of a StaggeredGrid's tile.
- StairedGridTile
- A tile of a staired pattern.
-
StreamSuperPaginationProvider<
T, R extends SuperPaginationRequest> - Stream-based pagination provider for real-time updates.
-
SuperPagination<
T, R extends SuperPaginationRequest> - SuperPaginationChangeListener
-
SuperPaginationColumn<
T, R extends SuperPaginationRequest> - A paginated Column widget (non-scrollable) with automatic pagination support.
-
SuperPaginationController<
T, R extends SuperPaginationRequest> -
SuperPaginationCubit<
T, R extends SuperPaginationRequest> -
SuperPaginationError<
T> -
SuperPaginationFilterChangeListener<
T> -
SuperPaginationGridView<
T, R extends SuperPaginationRequest> - A paginated GridView widget with automatic pagination support.
-
SuperPaginationInitial<
T> -
SuperPaginationListView<
T, R extends SuperPaginationRequest> - A paginated ListView widget with automatic pagination support.
-
SuperPaginationLoaded<
T> - SuperPaginationMeta
- Metadata describing the state of a paginated response.
-
SuperPaginationOrderChangeListener<
T> -
SuperPaginationPageView<
T, R extends SuperPaginationRequest> - A paginated PageView widget with automatic pagination support.
-
SuperPaginationProvider<
T, R extends SuperPaginationRequest> - Unified pagination data provider that can be either Future-based or Stream-based.
- SuperPaginationRefreshedChangeListener
-
SuperPaginationReorderableListView<
T, R extends SuperPaginationRequest> - A paginated ReorderableListView widget with automatic pagination support.
- SuperPaginationRequest
- Lightweight request descriptor used by the pagination cubit.
-
SuperPaginationRow<
T, R extends SuperPaginationRequest> - A paginated Row widget (horizontal non-scrollable) with automatic pagination support.
-
SuperPaginationStaggeredGridView<
T, R extends SuperPaginationRequest> - A paginated StaggeredGridView widget with automatic pagination support.
-
SuperPaginationState<
T> - SuperPaginationTheme
- GeniusLink-aligned visual tokens for the built-in pagination states.
- SuperSearchBottomSheetConfig
- Configuration for the bottom sheet search appearance.
-
SuperSearchBox<
T, K> - A search box widget that connects to a SuperPaginationCubit for searching.
- SuperSearchConfig
- Configuration for search behavior.
-
SuperSearchController<
T, K> - Controller for managing search state and connecting to SuperPaginationCubit.
-
SuperSearchDropdown<
T, K> - A convenient widget that combines search functionality with a dropdown overlay showing paginated results from a SuperPaginationCubit.
-
SuperSearchMultiController<
T, K> - Controller for managing multi-selection search state.
-
SuperSearchMultiDropdown<
T, K> - A widget that provides multi-selection search functionality with a dropdown.
-
SuperSearchOverlay<
T, K> - A widget that combines SuperSearchBox with an overlay dropdown for results.
- SuperSearchOverlayConfig
- Configuration for the search overlay appearance and behavior.
- SuperSearchTheme
- Theme extension for SuperSearch widgets.
- WovenGridTile
- A tile of a woven pattern.
Enums
- AnchorStrategy
- The strategy used to identify and restore a scroll anchor. Selected at capture time based on the available inputs (per the hybrid policy in spec Q1):
- ChatScrollObserverHandleMode
- ChatScrollObserverHandlePositionType
- ChatScrollObserverRefIndexType
- ErrorRetryStrategy
- Strategy for handling retry behavior after an error occurs.
- NestedScrollUtilPosition
- ObserverAutoTriggerObserveType
- Define type that auto trigger observe.
- ObserverRenderSliverType
- Define type of the observed render sliver.
- ObserverTriggerOnObserveType
-
Define type that trigger
onObservecallback. - OverlayAnimationType
- Animation types for overlay show/hide transitions.
- OverlayPosition
- Position preference for the search overlay.
- PaginateBuilderType
- SearchDisplayMode
- Display mode for search dropdowns.
- SortDirection
- Defines the direction of sorting.
Extensions
Typedefs
- ChatScrollObserverCustomAdjustPosition = double? Function(ChatScrollObserverCustomAdjustPositionModel)
- Customize the scroll position should be given new viewport dimensions.
- ChatScrollObserverCustomAdjustPositionDelta = double? Function(ChatScrollObserverCustomAdjustPositionDeltaModel)
- Customize the delta of the adjustPosition.
-
CompareBy<
T> = int Function(T a, T b) -
InsertAllCallback<
T> = void Function(List< T> currentItems, Iterable<T> newItems) - Signature for a callback function that is called when items are inserted.
-
ItemComparator<
T> = int Function(T a, T b) -
A comparator function that compares two items of type
T. -
ListBuilder<
T> = List< T> Function(List<T> list) - Signature for a function that builds a list from fetched items.
-
ObserverOnPrepareScrollToIndex
= Future<
bool> Function(ObservePrepareScrollToIndexModel) -
Called when the ObserverController prepare to scroll to index with
ObservePrepareScrollToIndexModel. -
OnInsertionCallback<
T> = void Function(List< T> items) -
OnObserveAllCallback<
M extends ObserveModel> = void Function(Map< BuildContext, M> resultMap) - The callback type of getting observed result map.
-
OnObserveCallback<
M extends ObserveModel> = void Function(M result) - The callback type of getting observed result for first sliver.
- OnObserveViewportCallback = void Function(SliverViewportObserveModel result)
- The callback type of getting all slivers those are displayed in viewport.
-
PaginationDataProvider<
T> = Future< List< Function(SuperPaginationRequest request)T> > - Legacy typedef for backward compatibility (will be deprecated).
-
PaginationStreamProvider<
T> = Stream< List< Function(SuperPaginationRequest request)T> > - Legacy typedef for backward compatibility (will be deprecated).
-
WhereChecker<
T> = bool Function(T item)
Exceptions / Errors
- PaginationException
- Custom exception types for pagination errors.
- PaginationNetworkException
- Exception thrown when a network request fails.
- PaginationParseException
- Exception thrown when data parsing fails.
- PaginationRetryExhaustedException
- Exception thrown when all retry attempts have been exhausted.
- PaginationTimeoutException
- Exception thrown when a network request times out.